summaryrefslogtreecommitdiffstats
path: root/kdgantt/KDGanttViewItem.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdgantt/KDGanttViewItem.cpp')
-rw-r--r--kdgantt/KDGanttViewItem.cpp126
1 files changed, 63 insertions, 63 deletions
diff --git a/kdgantt/KDGanttViewItem.cpp b/kdgantt/KDGanttViewItem.cpp
index 3d36683b..c250d22f 100644
--- a/kdgantt/KDGanttViewItem.cpp
+++ b/kdgantt/KDGanttViewItem.cpp
@@ -52,20 +52,20 @@
directly. Instead, you should create items of one of the
subclasses. This class provides methods common to all Gantt items.
- The initialization of the shapes/colors of the item works as follows:
+ The initialization of the tqshapes/colors of the item works as follows:
Shapes:
- When a new item is created, the shapes are set to the default values
+ When a new item is created, the tqshapes are set to the default values
for items of the type of this item, defined in the KDGanttView class with
void setShapes( KDGanttViewItem::Type type,
KDGanttViewItem::Shape start,
KDGanttViewItem::Shape middle,
KDGanttViewItem::Shape end );
If there is no default value defined for this type,
- the shapes are set as follows:
- For TaskViewItems all three shapes are set to Square.
- For SummaryViewItems all three shapes are set to TriangleDown.
- For EventViewItems all three shapes are set to Diamond.
+ the tqshapes are set as follows:
+ For TaskViewItems all three tqshapes are set to Square.
+ For SummaryViewItems all three tqshapes are set to TriangleDown.
+ For EventViewItems all three tqshapes are set to Diamond.
Colors:
When a new item is created, the colors are set to the default values
@@ -75,7 +75,7 @@
const TQColor& middle,
const TQColor& end );
If there is no default value defined for this type,
- the colors of the shapes are set to the default color for items of this type,
+ the colors of the tqshapes are set to the default color for items of this type,
defined in the KDGanttView class with:
void setDefaultColor( KDGanttViewItem::Type type, const TQColor& );
The initial default color in the KDGanttView class is set to
@@ -92,7 +92,7 @@
const TQColor& middle,
const TQColor& end );
If there is no default value defined for this type,
- the highlight colors of the shapes are set to the default color for
+ the highlight colors of the tqshapes are set to the default color for
items of this type, defined in the KDGanttView class with:
void setDefaultHighlightColor( KDGanttViewItem::Type type, const TQColor& );
The initial default highlight color in the KDGanttView class is set to red
@@ -138,7 +138,7 @@
Example 1, Color:
If you create an instance of a KDGanttView class and add a SummaryViewItem
- without setting any color/shape values, you get an item with three shapes
+ without setting any color/tqshape values, you get an item with three tqshapes
of the form TriangleDown in the color magenta. If the item is highlighted,
the color will change to the highlight color red.
@@ -773,16 +773,16 @@ bool KDGanttViewItem::highlight() const
/*!
- Specifies the shapes to be used for this item.
+ Specifies the tqshapes to be used for this item.
- It is advisable not to use this method, but rather set the shapes
+ It is advisable not to use this method, but rather set the tqshapes
for all items of a type with KDGanttView::setShapes() in order to
get a uniform Gantt view.
- \param start the start shape
- \param middle the middle shape
- \param end the end shape
- \sa shapes(), setColors(), colors()
+ \param start the start tqshape
+ \param middle the middle tqshape
+ \param end the end tqshape
+ \sa tqshapes(), setColors(), colors()
*/
void KDGanttViewItem::setShapes( Shape start, Shape middle, Shape end )
{
@@ -799,20 +799,20 @@ void KDGanttViewItem::setShapes( Shape start, Shape middle, Shape end )
/*!
- Creates shapes of the specified type \a shape.
- The background shape color is set to black and the background shape
- is slightly bit bigger than the foreground shape to have a black border
- around the foreground shape.
+ Creates tqshapes of the specified type \a tqshape.
+ The background tqshape color is set to black and the background tqshape
+ is slightly bit bigger than the foreground tqshape to have a black border
+ around the foreground tqshape.
- \param itemShape the foreground shape
- \param middle itemShapeBack the background shape
- \param shape the type of the shape
+ \param itemShape the foreground tqshape
+ \param middle itemShapeBack the background tqshape
+ \param tqshape the type of the tqshape
(may be TriangleDown, TriangleUp, Diamond, Square, Circle)
- \sa shapes(), setColors(), colors()
+ \sa tqshapes(), setColors(), colors()
*/
void KDGanttViewItem::createShape( KDCanvasPolygonItem* &itemShape,
KDCanvasPolygonItem* &itemShapeBack,
- Shape shape )
+ Shape tqshape )
{
if ( itemShape && type() == Task )
return;
@@ -823,7 +823,7 @@ void KDGanttViewItem::createShape( KDCanvasPolygonItem* &itemShape,
TQCanvasPolygonalItem * itemBack;
int size = myItemSize+2;
int hei = (myItemSize/3)/2;
- switch (shape) {
+ switch (tqshape) {
case TriangleDown:
{
item = new KDCanvasPolygon(myGanttView->myTimeTable, this,Type_is_KDGanttViewItem);
@@ -912,8 +912,8 @@ void KDGanttViewItem::createShape( KDCanvasPolygonItem* &itemShape,
break;
}
default:
// Uninitialized shape, can e.g. be the case with free-busy
// items which don't have any shapes
return;
}
item->setBrush(Qt::SolidPattern);
@@ -927,14 +927,14 @@ void KDGanttViewItem::createShape( KDCanvasPolygonItem* &itemShape,
/*!
- Returns the shapes used for this item
+ Returns the tqshapes used for this item
- \param start returns the start shape
- \param middle returns the middle shape
- \param end returns the end shape
+ \param start returns the start tqshape
+ \param middle returns the middle tqshape
+ \param end returns the end tqshape
\sa setShapes(), setColors(), colors()
*/
-void KDGanttViewItem::shapes( Shape& start, Shape& middle, Shape& end ) const
+void KDGanttViewItem::tqshapes( Shape& start, Shape& middle, Shape& end ) const
{
start = myStartShape;
middle = myMiddleShape;
@@ -943,16 +943,16 @@ void KDGanttViewItem::shapes( Shape& start, Shape& middle, Shape& end ) const
/*!
- Specifies the colors in which to draw the shapes of this item.
+ Specifies the colors in which to draw the tqshapes of this item.
It is advisable not to use this method, but rather set the colors
for all items of a type with KDGanttView::setColors() in order to
get a uniform Gantt view.
- \param start the color for the start shape
- \param middle the color for the middle shape
- \param end the color for the end shape
- \sa colors(), setShapes(), shapes(), setDefaultColor(), defaultColor()
+ \param start the color for the start tqshape
+ \param middle the color for the middle tqshape
+ \param end the color for the end tqshape
+ \sa colors(), setShapes(), tqshapes(), setDefaultColor(), defaultColor()
*/
void KDGanttViewItem::setColors( const TQColor& start, const TQColor& middle,
const TQColor& end )
@@ -980,7 +980,7 @@ void KDGanttViewItem::setColors( const TQColor& start, const TQColor& middle,
\param start returns the start color
\param middle returns the middle color
\param end returns the end color
- \sa setColors(), setShapes(), shapes(), setDefaultColor(), defaultColor()
+ \sa setColors(), setShapes(), tqshapes(), setDefaultColor(), defaultColor()
*/
void KDGanttViewItem::colors( TQColor& start, TQColor& middle, TQColor& end ) const
{
@@ -992,7 +992,7 @@ void KDGanttViewItem::colors( TQColor& start, TQColor& middle, TQColor& end ) co
/*!
- Specifies the highlight colors in which to draw the shapes of this item.
+ Specifies the highlight colors in which to draw the tqshapes of this item.
It is advisable not to use this method, but rather set the highlight
colors for all items of a type with
@@ -1003,10 +1003,10 @@ void KDGanttViewItem::colors( TQColor& start, TQColor& middle, TQColor& end ) co
(displaySubitemsAsGroup() == true)
all changes apply to all subitems as well.
- \param start the highlight color for the start shape
- \param middle the highlight color for the middle shape
- \param end the highlight color for the end shape
- \sa highlightColors(), setShapes(), shapes()
+ \param start the highlight color for the start tqshape
+ \param middle the highlight color for the middle tqshape
+ \param end the highlight color for the end tqshape
+ \sa highlightColors(), setShapes(), tqshapes()
*/
void KDGanttViewItem::setHighlightColors( const TQColor& start, const TQColor& middle, const TQColor& end )
{
@@ -1032,7 +1032,7 @@ void KDGanttViewItem::setHighlightColors( const TQColor& start, const TQColor& m
\param start returns the start highlight color
\param middle returns the middle highlight color
\param end returns the end highlight color
- \sa setHighlightColors(), setShapes(), shapes()
+ \sa setHighlightColors(), setShapes(), tqshapes()
*/
void KDGanttViewItem::highlightColors( TQColor& start, TQColor& middle, TQColor& end ) const
{
@@ -1086,7 +1086,7 @@ TQColor KDGanttViewItem::textColor() const
/*!
\enum KDGanttViewItem::Shape
- This enum is used in order to specify the shapes of a Gantt chart
+ This enum is used in order to specify the tqshapes of a Gantt chart
item.
*/
@@ -1469,10 +1469,10 @@ void KDGanttViewItem::initColorAndShapes(Type t)
setDefaultColor( myGanttView->defaultColor(myType));
// set default highlight color
setDefaultHighlightColor(myGanttView->defaultHighlightColor(myType));
- // set shapes
- if (!( shapeDefined = (myGanttView->shapes(myType,myStartShape,myMiddleShape,myEndShape)))) {
+ // set tqshapes
+ if (!( tqshapeDefined = (myGanttView->tqshapes(myType,myStartShape,myMiddleShape,myEndShape)))) {
- //qDebug("KDGantt::KDGanttViewItem created with not user defined shapes");
+ //qDebug("KDGantt::KDGanttViewItem created with not user defined tqshapes");
};
setShapes(myStartShape,myMiddleShape,myEndShape);
@@ -1486,12 +1486,12 @@ void KDGanttViewItem::initColorAndShapes(Type t)
floatStartShape = (KDCanvasPolygonItem*)new KDCanvasRectangle(myGanttView->myTimeTable,this,Type_is_KDGanttViewItem);
floatEndShape = (KDCanvasPolygonItem*)new KDCanvasRectangle(myGanttView->myTimeTable,this,Type_is_KDGanttViewItem);
// set color of shapes
if (!( colorDefined = (myGanttView->colors(myType,myStartColor,myMiddleColor,myEndColor)))) {
};
setColors(defaultColor(),defaultColor(), defaultColor());
// set highlight color of shapes
if (!( colorHLDefined = (myGanttView->highlightColors(myType,myStartColorHL,myMiddleColorHL,myEndColorHL)))) {
};
@@ -1508,9 +1508,9 @@ void KDGanttViewItem::initColorAndShapes(Type t)
}
-TQString KDGanttViewItem::shapeToString( Shape shape )
+TQString KDGanttViewItem::tqshapeToString( Shape tqshape )
{
- switch( shape ) {
+ switch( tqshape ) {
case TriangleDown:
return "TriangleDown";
case TriangleUp:
@@ -1571,13 +1571,13 @@ void KDGanttViewItem::createNode( TQDomDocument& doc,
KDGanttXML::createBoolNode( doc, itemElement, "Open", isOpen() );
KDGanttXML::createBoolNode( doc, itemElement, "Highlight", highlight() );
Shape startShape, middleShape, endShape;
- shapes( startShape, middleShape, endShape );
+ tqshapes( startShape, middleShape, endShape );
KDGanttXML::createStringNode( doc, itemElement, "StartShape",
- shapeToString( startShape ) );
+ tqshapeToString( startShape ) );
KDGanttXML::createStringNode( doc, itemElement, "MiddleShape",
- shapeToString( middleShape ) );
+ tqshapeToString( middleShape ) );
KDGanttXML::createStringNode( doc, itemElement, "EndShape",
- shapeToString( endShape ) );
+ tqshapeToString( endShape ) );
KDGanttXML::createColorNode( doc, itemElement, "DefaultColor", defaultColor() );
TQColor startColor, middleColor, endColor;
colors( startColor, middleColor, endColor );
@@ -2294,7 +2294,7 @@ void KDGanttViewItem::resetSubitemVisibility()
In calendar mode, only those items can be opened
which have subitems which have subitems.
An item which has subitems which have no subitems is called a calendar.
- I.e., an item that contains
+ I.e., an item that tqcontains
multiple calendars can be opened, while a calendar item itself cannot.
But if all calendars of an item do not have any subitem (e.g at startup),
the program cannot detect automatically that it should be possible to open
@@ -2365,37 +2365,37 @@ bool KDGanttViewItem::isCalendar( ) const
/*!
\var KDGanttViewItem::startShape
- the shape at the beginning of the item
+ the tqshape at the beginning of the item
*/
/*!
\var KDGanttViewItem::midShape
- the shape in the middle of the item
+ the tqshape in the middle of the item
*/
/*!
\var KDGanttViewItem::endShape
- the shape at the end of the item
+ the tqshape at the end of the item
*/
/*!
\var KDGanttViewItem::startShapeBack
- the background shape at the beginning of the item
+ the background tqshape at the beginning of the item
*/
/*!
\var KDGanttViewItem::midShapeBack
- the background shape in the middle of the item
+ the background tqshape in the middle of the item
*/
/*!
\var KDGanttViewItem::endShapeBack
- the background shape at the end of the item
+ the background tqshape at the end of the item
*/
@@ -912,8 +912,8 @@ void KDGanttViewItem::createShape( KDCanvasPolygonItem* &itemShape,
}
default:
- // Uninitialized shape, can e.g. be the case with free-busy
- // items which don't have any shapes
+ // Uninitialized tqshape, can e.g. be the case with free-busy
+ // items which don't have any tqshapes
return;
}
@@ -1486,12 +1486,12 @@ void KDGanttViewItem::initColorAndShapes(Type t)
floatStartShape = (KDCanvasPolygonItem*)new KDCanvasRectangle(myGanttView->myTimeTable,this,Type_is_KDGanttViewItem);
floatEndShape = (KDCanvasPolygonItem*)new KDCanvasRectangle(myGanttView->myTimeTable,this,Type_is_KDGanttViewItem);
- // set color of shapes
+ // set color of tqshapes
if (!( colorDefined = (myGanttView->colors(myType,myStartColor,myMiddleColor,myEndColor)))) {
};
@@ -1486,12 +1486,12 @@ void KDGanttViewItem::initColorAndShapes(Type t)
};
setColors(defaultColor(),defaultColor(), defaultColor());
- // set highlight color of shapes
+ // set highlight color of tqshapes
if (!( colorHLDefined = (myGanttView->highlightColors(myType,myStartColorHL,myMiddleColorHL,myEndColorHL)))) {
};